git.delta.rocks / unique-network / refs/commits / 6afd9fe97b2d

difftreelog

misk: update stubs

Trubnikov Sergey2022-10-25parent: #846b910.patch.diff
in: master

7 files changed

modifiedpallets/nonfungible/src/stubs/UniqueNFT.soldiffbeforeafterboth
--- a/pallets/nonfungible/src/stubs/UniqueNFT.sol
+++ b/pallets/nonfungible/src/stubs/UniqueNFT.sol
@@ -106,6 +106,7 @@
 /// @title A contract that allows you to work with collections.
 <<<<<<< HEAD
 <<<<<<< HEAD
+<<<<<<< HEAD
 /// @dev the ERC-165 identifier for this interface is 0xb3152af3
 =======
 /// @dev the ERC-165 identifier for this interface is 0x674be726
@@ -113,6 +114,9 @@
 =======
 /// @dev the ERC-165 identifier for this interface is 0x943ee094
 >>>>>>> fix: after rebase
+=======
+/// @dev the ERC-165 identifier for this interface is 0xefe988e0
+>>>>>>> misk: update stubs
 contract Collection is Dummy, ERC165 {
 	/// Set collection property.
 	///
@@ -130,7 +134,7 @@
 	/// Set collection properties.
 	///
 	/// @param properties Vector of properties key/value pair.
-	/// @dev EVM selector for this function is: 0xf90c1ce9,
+	/// @dev EVM selector for this function is: 0x50b26b2a,
 	///  or in textual repr: setCollectionProperties((string,bytes)[])
 	function setCollectionProperties(Tuple21[] memory properties) public {
 		require(false, stub_error);
@@ -152,7 +156,7 @@
 	/// Delete collection properties.
 	///
 	/// @param keys Properties keys.
-	/// @dev EVM selector for this function is: 0x56d4684a,
+	/// @dev EVM selector for this function is: 0xee206ee3,
 	///  or in textual repr: deleteCollectionProperties(string[])
 	function deleteCollectionProperties(string[] memory keys) public {
 		require(false, stub_error);
@@ -179,7 +183,7 @@
 	///
 	/// @param keys Properties keys. Empty keys for all propertyes.
 	/// @return Vector of properties key/value pairs.
-	/// @dev EVM selector for this function is: 0x5cad7311,
+	/// @dev EVM selector for this function is: 0x285fb8e6,
 	///  or in textual repr: collectionProperties(string[])
 	function collectionProperties(string[] memory keys) public view returns (Tuple21[] memory) {
 		require(false, stub_error);
@@ -206,9 +210,16 @@
 	/// @dev In order for sponsorship to work, it must be confirmed on behalf of the sponsor.
 	///
 	/// @param sponsor Cross account address of the sponsor from whose account funds will be debited for operations with the contract.
+<<<<<<< HEAD
 	/// @dev EVM selector for this function is: 0x403e96a7,
 	///  or in textual repr: setCollectionSponsorCross((address,uint256))
 	function setCollectionSponsorCross(Tuple6 memory sponsor) public {
+=======
+	/// @dev EVM selector for this function is: 0x84a1d5a8,
+	///  or in textual repr: setCollectionSponsorCross(EthCrossAccount)
+	///  or in the expanded repr: setCollectionSponsorCross((address,uint256))
+	function setCollectionSponsorCross(EthCrossAccount memory sponsor) public {
+>>>>>>> misk: update stubs
 		require(false, stub_error);
 		sponsor;
 		dummy = 0;
@@ -248,6 +259,7 @@
 	///  or in textual repr: collectionSponsor()
 <<<<<<< HEAD
 <<<<<<< HEAD
+<<<<<<< HEAD
 	function collectionSponsor() public view returns (Tuple6 memory) {
 		require(false, stub_error);
 		dummy;
@@ -264,6 +276,12 @@
 		dummy;
 		return Tuple8(0x0000000000000000000000000000000000000000, 0);
 >>>>>>> feat: Add custum signature with unlimited nesting.
+=======
+	function collectionSponsor() public view returns (Tuple24 memory) {
+		require(false, stub_error);
+		dummy;
+		return Tuple24(0x0000000000000000000000000000000000000000, 0);
+>>>>>>> misk: update stubs
 	}
 
 	/// Set limits for the collection.
@@ -312,9 +330,16 @@
 
 	/// Add collection admin.
 	/// @param newAdmin Cross account administrator address.
+<<<<<<< HEAD
 	/// @dev EVM selector for this function is: 0x62e3c7c2,
 	///  or in textual repr: addCollectionAdminCross((address,uint256))
 	function addCollectionAdminCross(Tuple6 memory newAdmin) public {
+=======
+	/// @dev EVM selector for this function is: 0x859aa7d6,
+	///  or in textual repr: addCollectionAdminCross(EthCrossAccount)
+	///  or in the expanded repr: addCollectionAdminCross((address,uint256))
+	function addCollectionAdminCross(EthCrossAccount memory newAdmin) public {
+>>>>>>> misk: update stubs
 		require(false, stub_error);
 		newAdmin;
 		dummy = 0;
@@ -322,9 +347,16 @@
 
 	/// Remove collection admin.
 	/// @param admin Cross account administrator address.
+<<<<<<< HEAD
 	/// @dev EVM selector for this function is: 0x810d1503,
 	///  or in textual repr: removeCollectionAdminCross((address,uint256))
 	function removeCollectionAdminCross(Tuple6 memory admin) public {
+=======
+	/// @dev EVM selector for this function is: 0x6c0cd173,
+	///  or in textual repr: removeCollectionAdminCross(EthCrossAccount)
+	///  or in the expanded repr: removeCollectionAdminCross((address,uint256))
+	function removeCollectionAdminCross(EthCrossAccount memory admin) public {
+>>>>>>> misk: update stubs
 		require(false, stub_error);
 		admin;
 		dummy = 0;
@@ -366,7 +398,7 @@
 	///
 	/// @param enable If "true" degenerates to nesting: {OwnerRestricted: [1, 2, 3]} else to nesting: 'Disabled'
 	/// @param collections Addresses of collections that will be available for nesting.
-	/// @dev EVM selector for this function is: 0x112d4586,
+	/// @dev EVM selector for this function is: 0x64872396,
 	///  or in textual repr: setCollectionNesting(bool,address[])
 	function setCollectionNesting(bool enable, address[] memory collections) public {
 		require(false, stub_error);
@@ -413,9 +445,16 @@
 	/// Add user to allowed list.
 	///
 	/// @param user User cross account address.
+<<<<<<< HEAD
 	/// @dev EVM selector for this function is: 0xf074da88,
 	///  or in textual repr: addToCollectionAllowListCross((address,uint256))
 	function addToCollectionAllowListCross(Tuple6 memory user) public {
+=======
+	/// @dev EVM selector for this function is: 0xa0184a3a,
+	///  or in textual repr: addToCollectionAllowListCross(EthCrossAccount)
+	///  or in the expanded repr: addToCollectionAllowListCross((address,uint256))
+	function addToCollectionAllowListCross(EthCrossAccount memory user) public {
+>>>>>>> misk: update stubs
 		require(false, stub_error);
 		user;
 		dummy = 0;
@@ -435,9 +474,16 @@
 	/// Remove user from allowed list.
 	///
 	/// @param user User cross account address.
+<<<<<<< HEAD
 	/// @dev EVM selector for this function is: 0xc00df45c,
 	///  or in textual repr: removeFromCollectionAllowListCross((address,uint256))
 	function removeFromCollectionAllowListCross(Tuple6 memory user) public {
+=======
+	/// @dev EVM selector for this function is: 0x09ba452a,
+	///  or in textual repr: removeFromCollectionAllowListCross(EthCrossAccount)
+	///  or in the expanded repr: removeFromCollectionAllowListCross((address,uint256))
+	function removeFromCollectionAllowListCross(EthCrossAccount memory user) public {
+>>>>>>> misk: update stubs
 		require(false, stub_error);
 		user;
 		dummy = 0;
@@ -471,9 +517,16 @@
 	///
 	/// @param user User cross account to verify
 	/// @return "true" if account is the owner or admin
+<<<<<<< HEAD
 	/// @dev EVM selector for this function is: 0x5aba3351,
 	///  or in textual repr: isOwnerOrAdminCross((address,uint256))
 	function isOwnerOrAdminCross(Tuple6 memory user) public view returns (bool) {
+=======
+	/// @dev EVM selector for this function is: 0x3e75a905,
+	///  or in textual repr: isOwnerOrAdminCross(EthCrossAccount)
+	///  or in the expanded repr: isOwnerOrAdminCross((address,uint256))
+	function isOwnerOrAdminCross(EthCrossAccount memory user) public view returns (bool) {
+>>>>>>> misk: update stubs
 		require(false, stub_error);
 		user;
 		dummy;
@@ -499,6 +552,7 @@
 	///  or in textual repr: collectionOwner()
 <<<<<<< HEAD
 <<<<<<< HEAD
+<<<<<<< HEAD
 	function collectionOwner() public view returns (Tuple6 memory) {
 		require(false, stub_error);
 		dummy;
@@ -515,6 +569,12 @@
 		dummy;
 		return Tuple8(0x0000000000000000000000000000000000000000, 0);
 >>>>>>> feat: Add custum signature with unlimited nesting.
+=======
+	function collectionOwner() public view returns (EthCrossAccount memory) {
+		require(false, stub_error);
+		dummy;
+		return EthCrossAccount(0x0000000000000000000000000000000000000000, 0);
+>>>>>>> misk: update stubs
 	}
 
 	/// Changes collection owner to another account
@@ -535,19 +595,33 @@
 	/// If address is canonical then substrate mirror is zero and vice versa.
 	/// @dev EVM selector for this function is: 0x5813216b,
 	///  or in textual repr: collectionAdmins()
+<<<<<<< HEAD
 	function collectionAdmins() public view returns (Tuple6[] memory) {
 		require(false, stub_error);
 		dummy;
 		return new Tuple6[](0);
+=======
+	function collectionAdmins() public view returns (EthCrossAccount[] memory) {
+		require(false, stub_error);
+		dummy;
+		return new EthCrossAccount[](0);
+>>>>>>> misk: update stubs
 	}
 
 	/// Changes collection owner to another account
 	///
 	/// @dev Owner can be changed only by current owner
 	/// @param newOwner new owner cross account
+<<<<<<< HEAD
 	/// @dev EVM selector for this function is: 0xbdff793d,
 	///  or in textual repr: setOwnerCross((address,uint256))
 	function setOwnerCross(Tuple6 memory newOwner) public {
+=======
+	/// @dev EVM selector for this function is: 0xe5c9913f,
+	///  or in textual repr: setOwnerCross(EthCrossAccount)
+	///  or in the expanded repr: setOwnerCross((address,uint256))
+	function setOwnerCross(EthCrossAccount memory newOwner) public {
+>>>>>>> misk: update stubs
 		require(false, stub_error);
 		newOwner;
 		dummy = 0;
@@ -556,12 +630,24 @@
 
 <<<<<<< HEAD
 <<<<<<< HEAD
+<<<<<<< HEAD
 /// @dev anonymous struct
 struct Tuple19 {
+=======
+/// @dev Cross account struct
+struct EthCrossAccount {
+	address eth;
+	uint256 sub;
+}
+
+/// @dev anonymous struct
+struct Tuple24 {
+>>>>>>> misk: update stubs
 	address field_0;
 	uint256 field_1;
 }
 
+<<<<<<< HEAD
 /// @title ERC-721 Non-Fungible Token Standard, optional metadata extension
 /// @dev See https://eips.ethereum.org/EIPS/eip-721
 /// @dev the ERC-165 identifier for this interface is 0x5b5e139f
@@ -608,6 +694,8 @@
 =======
 >>>>>>> feat: Add custum signature with unlimited nesting.
 =======
+=======
+>>>>>>> misk: update stubs
 /// @dev anonymous struct
 struct Tuple21 {
 	string field_0;
@@ -717,10 +805,14 @@
 
 /// @title Unique extensions for ERC721.
 <<<<<<< HEAD
+<<<<<<< HEAD
 /// @dev the ERC-165 identifier for this interface is 0x244543ee
 =======
 /// @dev the ERC-165 identifier for this interface is 0xcc97cb35
 >>>>>>> feat: Add custum signature with unlimited nesting.
+=======
+/// @dev the ERC-165 identifier for this interface is 0xb76006ac
+>>>>>>> misk: update stubs
 contract ERC721UniqueExtensions is Dummy, ERC165 {
 	/// @notice A descriptive name for a collection of NFTs in this contract
 	/// @dev EVM selector for this function is: 0x06fdde03,
@@ -746,9 +838,16 @@
 	///  operator of the current owner.
 	/// @param approved The new substrate address approved NFT controller
 	/// @param tokenId The NFT to approve
+<<<<<<< HEAD
 	/// @dev EVM selector for this function is: 0x106fdb59,
 	///  or in textual repr: approveCross((address,uint256),uint256)
 	function approveCross(Tuple6 memory approved, uint256 tokenId) public {
+=======
+	/// @dev EVM selector for this function is: 0x0ecd0ab0,
+	///  or in textual repr: approveCross(EthCrossAccount,uint256)
+	///  or in the expanded repr: approveCross((address,uint256),uint256)
+	function approveCross(EthCrossAccount memory approved, uint256 tokenId) public {
+>>>>>>> misk: update stubs
 		require(false, stub_error);
 		approved;
 		tokenId;
@@ -777,6 +876,7 @@
 	/// @param tokenId The NFT to transfer
 	/// @dev EVM selector for this function is: 0xd5cf430b,
 	///  or in textual repr: transferFromCross(EthCrossAccount,EthCrossAccount,uint256)
+	///  or in the expanded repr: transferFromCross((address,uint256),(address,uint256),uint256)
 	function transferFromCross(
 <<<<<<< HEAD
 		Tuple6 memory from,
@@ -815,9 +915,16 @@
 	///  if `to` is the zero address. Throws if `tokenId` is not a valid NFT.
 	/// @param from The current owner of the NFT
 	/// @param tokenId The NFT to transfer
+<<<<<<< HEAD
 	/// @dev EVM selector for this function is: 0xa8106d4a,
 	///  or in textual repr: burnFromCross((address,uint256),uint256)
 	function burnFromCross(Tuple6 memory from, uint256 tokenId) public {
+=======
+	/// @dev EVM selector for this function is: 0xbb2f5a58,
+	///  or in textual repr: burnFromCross(EthCrossAccount,uint256)
+	///  or in the expanded repr: burnFromCross((address,uint256),uint256)
+	function burnFromCross(EthCrossAccount memory from, uint256 tokenId) public {
+>>>>>>> misk: update stubs
 		require(false, stub_error);
 		from;
 		tokenId;
@@ -873,7 +980,7 @@
 	///  should be obtained with `nextTokenId` method
 	/// @param to The new owner
 	/// @param tokenIds IDs of the minted NFTs
-	/// @dev EVM selector for this function is: 0xf9d9a5a3,
+	/// @dev EVM selector for this function is: 0x44a9945e,
 	///  or in textual repr: mintBulk(address,uint256[])
 	function mintBulk(address to, uint256[] memory tokenIds) public returns (bool) {
 		require(false, stub_error);
@@ -888,7 +995,7 @@
 	///  numbers and first number should be obtained with `nextTokenId` method
 	/// @param to The new owner
 	/// @param tokens array of pairs of token ID and token URI for minted tokens
-	/// @dev EVM selector for this function is: 0xfd4e2a99,
+	/// @dev EVM selector for this function is: 0x36543006,
 	///  or in textual repr: mintBulkWithTokenURI(address,(uint256,string)[])
 	function mintBulkWithTokenURI(address to, Tuple12[] memory tokens) public returns (bool) {
 		require(false, stub_error);
@@ -907,6 +1014,7 @@
 }
 
 <<<<<<< HEAD
+<<<<<<< HEAD
 /// @dev anonymous struct
 struct Tuple6 {
 	address field_0;
@@ -925,6 +1033,8 @@
 	uint256 field_1;
 }
 
+=======
+>>>>>>> misk: update stubs
 /// @title ERC-721 Non-Fungible Token Standard, optional enumeration extension
 /// @dev See https://eips.ethereum.org/EIPS/eip-721
 /// @dev the ERC-165 identifier for this interface is 0x780e9d63
modifiedpallets/refungible/src/stubs/UniqueRefungible.soldiffbeforeafterboth
124 /// @param properties Vector of properties key/value pair.124 /// @param properties Vector of properties key/value pair.
125 /// @dev EVM selector for this function is: 0x50b26b2a,125 /// @dev EVM selector for this function is: 0x50b26b2a,
126 /// or in textual repr: setCollectionProperties((string,bytes)[])126 /// or in textual repr: setCollectionProperties((string,bytes)[])
127 function setCollectionProperties(Tuple19[] memory properties) public {127 function setCollectionProperties(Tuple20[] memory properties) public {
128 require(false, stub_error);128 require(false, stub_error);
129 properties;129 properties;
130 dummy = 0;130 dummy = 0;
173 /// @return Vector of properties key/value pairs.173 /// @return Vector of properties key/value pairs.
174 /// @dev EVM selector for this function is: 0x285fb8e6,174 /// @dev EVM selector for this function is: 0x285fb8e6,
175 /// or in textual repr: collectionProperties(string[])175 /// or in textual repr: collectionProperties(string[])
176 function collectionProperties(string[] memory keys) public view returns (Tuple19[] memory) {176 function collectionProperties(string[] memory keys) public view returns (Tuple20[] memory) {
177 require(false, stub_error);177 require(false, stub_error);
178 keys;178 keys;
179 dummy;179 dummy;
180 return new Tuple19[](0);180 return new Tuple20[](0);
181 }181 }
182182
183 /// Set the sponsor of the collection.183 /// Set the sponsor of the collection.
199 ///199 ///
200 /// @param sponsor Cross account address of the sponsor from whose account funds will be debited for operations with the contract.200 /// @param sponsor Cross account address of the sponsor from whose account funds will be debited for operations with the contract.
201 /// @dev EVM selector for this function is: 0x84a1d5a8,201 /// @dev EVM selector for this function is: 0x84a1d5a8,
202<<<<<<< HEAD
202 /// or in textual repr: setCollectionSponsorCross((address,uint256))203 /// or in textual repr: setCollectionSponsorCross((address,uint256))
203 function setCollectionSponsorCross(Tuple6 memory sponsor) public {204 function setCollectionSponsorCross(Tuple6 memory sponsor) public {
205=======
206 /// or in textual repr: setCollectionSponsorCross(EthCrossAccount)
207 /// or in the expanded repr: setCollectionSponsorCross((address,uint256))
208 function setCollectionSponsorCross(EthCrossAccount memory sponsor) public {
209>>>>>>> misk: update stubs
204 require(false, stub_error);210 require(false, stub_error);
205 sponsor;211 sponsor;
206 dummy = 0;212 dummy = 0;
238 /// @return Tuble with sponsor address and his substrate mirror. If there is no confirmed sponsor error "Contract has no sponsor" throw.244 /// @return Tuble with sponsor address and his substrate mirror. If there is no confirmed sponsor error "Contract has no sponsor" throw.
239 /// @dev EVM selector for this function is: 0x6ec0a9f1,245 /// @dev EVM selector for this function is: 0x6ec0a9f1,
240 /// or in textual repr: collectionSponsor()246 /// or in textual repr: collectionSponsor()
247<<<<<<< HEAD
241 function collectionSponsor() public view returns (Tuple6 memory) {248 function collectionSponsor() public view returns (Tuple6 memory) {
242 require(false, stub_error);249 require(false, stub_error);
243 dummy;250 dummy;
244 return Tuple6(0x0000000000000000000000000000000000000000, 0);251 return Tuple6(0x0000000000000000000000000000000000000000, 0);
252=======
253 function collectionSponsor() public view returns (Tuple23 memory) {
254 require(false, stub_error);
255 dummy;
256 return Tuple23(0x0000000000000000000000000000000000000000, 0);
257>>>>>>> misk: update stubs
245 }258 }
246259
247 /// Set limits for the collection.260 /// Set limits for the collection.
291 /// Add collection admin.304 /// Add collection admin.
292 /// @param newAdmin Cross account administrator address.305 /// @param newAdmin Cross account administrator address.
293 /// @dev EVM selector for this function is: 0x859aa7d6,306 /// @dev EVM selector for this function is: 0x859aa7d6,
307<<<<<<< HEAD
294 /// or in textual repr: addCollectionAdminCross((address,uint256))308 /// or in textual repr: addCollectionAdminCross((address,uint256))
295 function addCollectionAdminCross(Tuple6 memory newAdmin) public {309 function addCollectionAdminCross(Tuple6 memory newAdmin) public {
310=======
311 /// or in textual repr: addCollectionAdminCross(EthCrossAccount)
312 /// or in the expanded repr: addCollectionAdminCross((address,uint256))
313 function addCollectionAdminCross(EthCrossAccount memory newAdmin) public {
314>>>>>>> misk: update stubs
296 require(false, stub_error);315 require(false, stub_error);
297 newAdmin;316 newAdmin;
298 dummy = 0;317 dummy = 0;
301 /// Remove collection admin.320 /// Remove collection admin.
302 /// @param admin Cross account administrator address.321 /// @param admin Cross account administrator address.
303 /// @dev EVM selector for this function is: 0x6c0cd173,322 /// @dev EVM selector for this function is: 0x6c0cd173,
323<<<<<<< HEAD
304 /// or in textual repr: removeCollectionAdminCross((address,uint256))324 /// or in textual repr: removeCollectionAdminCross((address,uint256))
305 function removeCollectionAdminCross(Tuple6 memory admin) public {325 function removeCollectionAdminCross(Tuple6 memory admin) public {
326=======
327 /// or in textual repr: removeCollectionAdminCross(EthCrossAccount)
328 /// or in the expanded repr: removeCollectionAdminCross((address,uint256))
329 function removeCollectionAdminCross(EthCrossAccount memory admin) public {
330>>>>>>> misk: update stubs
306 require(false, stub_error);331 require(false, stub_error);
307 admin;332 admin;
308 dummy = 0;333 dummy = 0;
392 ///417 ///
393 /// @param user User cross account address.418 /// @param user User cross account address.
394 /// @dev EVM selector for this function is: 0xa0184a3a,419 /// @dev EVM selector for this function is: 0xa0184a3a,
420<<<<<<< HEAD
395 /// or in textual repr: addToCollectionAllowListCross((address,uint256))421 /// or in textual repr: addToCollectionAllowListCross((address,uint256))
396 function addToCollectionAllowListCross(Tuple6 memory user) public {422 function addToCollectionAllowListCross(Tuple6 memory user) public {
423=======
424 /// or in textual repr: addToCollectionAllowListCross(EthCrossAccount)
425 /// or in the expanded repr: addToCollectionAllowListCross((address,uint256))
426 function addToCollectionAllowListCross(EthCrossAccount memory user) public {
427>>>>>>> misk: update stubs
397 require(false, stub_error);428 require(false, stub_error);
398 user;429 user;
399 dummy = 0;430 dummy = 0;
414 ///445 ///
415 /// @param user User cross account address.446 /// @param user User cross account address.
416 /// @dev EVM selector for this function is: 0x09ba452a,447 /// @dev EVM selector for this function is: 0x09ba452a,
448<<<<<<< HEAD
417 /// or in textual repr: removeFromCollectionAllowListCross((address,uint256))449 /// or in textual repr: removeFromCollectionAllowListCross((address,uint256))
418 function removeFromCollectionAllowListCross(Tuple6 memory user) public {450 function removeFromCollectionAllowListCross(Tuple6 memory user) public {
451=======
452 /// or in textual repr: removeFromCollectionAllowListCross(EthCrossAccount)
453 /// or in the expanded repr: removeFromCollectionAllowListCross((address,uint256))
454 function removeFromCollectionAllowListCross(EthCrossAccount memory user) public {
455>>>>>>> misk: update stubs
419 require(false, stub_error);456 require(false, stub_error);
420 user;457 user;
421 dummy = 0;458 dummy = 0;
450 /// @param user User cross account to verify487 /// @param user User cross account to verify
451 /// @return "true" if account is the owner or admin488 /// @return "true" if account is the owner or admin
452 /// @dev EVM selector for this function is: 0x3e75a905,489 /// @dev EVM selector for this function is: 0x3e75a905,
490<<<<<<< HEAD
453 /// or in textual repr: isOwnerOrAdminCross((address,uint256))491 /// or in textual repr: isOwnerOrAdminCross((address,uint256))
454 function isOwnerOrAdminCross(Tuple6 memory user) public view returns (bool) {492 function isOwnerOrAdminCross(Tuple6 memory user) public view returns (bool) {
493=======
494 /// or in textual repr: isOwnerOrAdminCross(EthCrossAccount)
495 /// or in the expanded repr: isOwnerOrAdminCross((address,uint256))
496 function isOwnerOrAdminCross(EthCrossAccount memory user) public view returns (bool) {
497>>>>>>> misk: update stubs
455 require(false, stub_error);498 require(false, stub_error);
456 user;499 user;
457 dummy;500 dummy;
471514
472 /// Get collection owner.515 /// Get collection owner.
473 ///516 ///
474 /// @return Tuble with sponsor address and his substrate mirror.517 /// @return Tuple with sponsor address and his substrate mirror.
475 /// If address is canonical then substrate mirror is zero and vice versa.518 /// If address is canonical then substrate mirror is zero and vice versa.
476 /// @dev EVM selector for this function is: 0xdf727d3b,519 /// @dev EVM selector for this function is: 0xdf727d3b,
477 /// or in textual repr: collectionOwner()520 /// or in textual repr: collectionOwner()
521<<<<<<< HEAD
478 function collectionOwner() public view returns (Tuple6 memory) {522 function collectionOwner() public view returns (Tuple6 memory) {
479 require(false, stub_error);523 require(false, stub_error);
480 dummy;524 dummy;
481 return Tuple6(0x0000000000000000000000000000000000000000, 0);525 return Tuple6(0x0000000000000000000000000000000000000000, 0);
526=======
527 function collectionOwner() public view returns (EthCrossAccount memory) {
528 require(false, stub_error);
529 dummy;
530 return EthCrossAccount(0x0000000000000000000000000000000000000000, 0);
531>>>>>>> misk: update stubs
482 }532 }
483533
484 /// Changes collection owner to another account534 /// Changes collection owner to another account
499 /// If address is canonical then substrate mirror is zero and vice versa.549 /// If address is canonical then substrate mirror is zero and vice versa.
500 /// @dev EVM selector for this function is: 0x5813216b,550 /// @dev EVM selector for this function is: 0x5813216b,
501 /// or in textual repr: collectionAdmins()551 /// or in textual repr: collectionAdmins()
552<<<<<<< HEAD
502 function collectionAdmins() public view returns (Tuple6[] memory) {553 function collectionAdmins() public view returns (Tuple6[] memory) {
503 require(false, stub_error);554 require(false, stub_error);
504 dummy;555 dummy;
505 return new Tuple6[](0);556 return new Tuple6[](0);
557=======
558 function collectionAdmins() public view returns (EthCrossAccount[] memory) {
559 require(false, stub_error);
560 dummy;
561 return new EthCrossAccount[](0);
562>>>>>>> misk: update stubs
506 }563 }
507564
508 /// Changes collection owner to another account565 /// Changes collection owner to another account
509 ///566 ///
510 /// @dev Owner can be changed only by current owner567 /// @dev Owner can be changed only by current owner
511 /// @param newOwner new owner cross account568 /// @param newOwner new owner cross account
512 /// @dev EVM selector for this function is: 0xe5c9913f,569 /// @dev EVM selector for this function is: 0xe5c9913f,
570<<<<<<< HEAD
513 /// or in textual repr: setOwnerCross((address,uint256))571 /// or in textual repr: setOwnerCross((address,uint256))
514 function setOwnerCross(Tuple6 memory newOwner) public {572 function setOwnerCross(Tuple6 memory newOwner) public {
573=======
574 /// or in textual repr: setOwnerCross(EthCrossAccount)
575 /// or in the expanded repr: setOwnerCross((address,uint256))
576 function setOwnerCross(EthCrossAccount memory newOwner) public {
577>>>>>>> misk: update stubs
515 require(false, stub_error);578 require(false, stub_error);
516 newOwner;579 newOwner;
517 dummy = 0;580 dummy = 0;
518 }581 }
519}582}
520583
584/// @dev Cross account struct
585struct EthCrossAccount {
586 address eth;
587 uint256 sub;
588}
589
521/// @dev anonymous struct590/// @dev anonymous struct
522struct Tuple19 {591struct Tuple23 {
592 address field_0;
593 uint256 field_1;
594}
595
596/// @dev anonymous struct
597struct Tuple20 {
523 string field_0;598 string field_0;
524 bytes field_1;599 bytes field_1;
525}600}
708 /// @param to The new owner783 /// @param to The new owner
709 /// @param tokenId The RFT to transfer784 /// @param tokenId The RFT to transfer
710 /// @dev EVM selector for this function is: 0xd5cf430b,785 /// @dev EVM selector for this function is: 0xd5cf430b,
711 /// or in textual repr: transferFromCross((address,uint256),(address,uint256),uint256)786 /// or in textual repr: transferFromCross(EthCrossAccount,EthCrossAccount,uint256)
787 /// or in the expanded repr: transferFromCross((address,uint256),(address,uint256),uint256)
712 function transferFromCross(788 function transferFromCross(
789<<<<<<< HEAD
713 Tuple6 memory from,790 Tuple6 memory from,
714 Tuple6 memory to,791 Tuple6 memory to,
792=======
793 EthCrossAccount memory from,
794 EthCrossAccount memory to,
795>>>>>>> misk: update stubs
715 uint256 tokenId796 uint256 tokenId
716 ) public {797 ) public {
717 require(false, stub_error);798 require(false, stub_error);
745 /// @param from The current owner of the RFT826 /// @param from The current owner of the RFT
746 /// @param tokenId The RFT to transfer827 /// @param tokenId The RFT to transfer
747 /// @dev EVM selector for this function is: 0xbb2f5a58,828 /// @dev EVM selector for this function is: 0xbb2f5a58,
829<<<<<<< HEAD
748 /// or in textual repr: burnFromCross((address,uint256),uint256)830 /// or in textual repr: burnFromCross((address,uint256),uint256)
749 function burnFromCross(Tuple6 memory from, uint256 tokenId) public {831 function burnFromCross(Tuple6 memory from, uint256 tokenId) public {
832=======
833 /// or in textual repr: burnFromCross(EthCrossAccount,uint256)
834 /// or in the expanded repr: burnFromCross((address,uint256),uint256)
835 function burnFromCross(EthCrossAccount memory from, uint256 tokenId) public {
836>>>>>>> misk: update stubs
750 require(false, stub_error);837 require(false, stub_error);
751 from;838 from;
752 tokenId;839 tokenId;
762 return 0;849 return 0;
763 }850 }
764851
852<<<<<<< HEAD
765 // /// @notice Function to mint multiple tokens.853 // /// @notice Function to mint multiple tokens.
766 // /// @dev `tokenIds` should be an array of consecutive numbers and first number854 // /// @dev `tokenIds` should be an array of consecutive numbers and first number
767 // /// should be obtained with `nextTokenId` method855 // /// should be obtained with `nextTokenId` method
791 // dummy = 0;879 // dummy = 0;
792 // return false;880 // return false;
793 // }881 // }
882=======
883 /// @notice Function to mint multiple tokens.
884 /// @dev `tokenIds` should be an array of consecutive numbers and first number
885 /// should be obtained with `nextTokenId` method
886 /// @param to The new owner
887 /// @param tokenIds IDs of the minted RFTs
888 /// @dev EVM selector for this function is: 0x44a9945e,
889 /// or in textual repr: mintBulk(address,uint256[])
890 function mintBulk(address to, uint256[] memory tokenIds) public returns (bool) {
891 require(false, stub_error);
892 to;
893 tokenIds;
894 dummy = 0;
895 return false;
896 }
897
898 /// @notice Function to mint multiple tokens with the given tokenUris.
899 /// @dev `tokenIds` is array of pairs of token ID and token URI. Token IDs should be consecutive
900 /// numbers and first number should be obtained with `nextTokenId` method
901 /// @param to The new owner
902 /// @param tokens array of pairs of token ID and token URI for minted tokens
903 /// @dev EVM selector for this function is: 0x36543006,
904 /// or in textual repr: mintBulkWithTokenURI(address,(uint256,string)[])
905 function mintBulkWithTokenURI(address to, Tuple11[] memory tokens) public returns (bool) {
906 require(false, stub_error);
907 to;
908 tokens;
909 dummy = 0;
910 return false;
911 }
912>>>>>>> misk: update stubs
794913
795 /// Returns EVM address for refungible token914 /// Returns EVM address for refungible token
796 ///915 ///
806}925}
807926
808/// @dev anonymous struct927/// @dev anonymous struct
928<<<<<<< HEAD
809struct Tuple8 {929struct Tuple8 {
930=======
931struct Tuple11 {
932>>>>>>> misk: update stubs
810 uint256 field_0;933 uint256 field_0;
811 string field_1;934 string field_1;
812}935}
813936
937<<<<<<< HEAD
814/// @dev anonymous struct938/// @dev anonymous struct
815struct Tuple6 {939struct Tuple6 {
816 address field_0;940 address field_0;
817 uint256 field_1;941 uint256 field_1;
818}942}
819943
944=======
945>>>>>>> misk: update stubs
820/// @title ERC-721 Non-Fungible Token Standard, optional enumeration extension946/// @title ERC-721 Non-Fungible Token Standard, optional enumeration extension
821/// @dev See https://eips.ethereum.org/EIPS/eip-721947/// @dev See https://eips.ethereum.org/EIPS/eip-721
822/// @dev the ERC-165 identifier for this interface is 0x780e9d63948/// @dev the ERC-165 identifier for this interface is 0x780e9d63
modifiedtests/src/eth/api/UniqueNFT.soldiffbeforeafterboth
--- a/tests/src/eth/api/UniqueNFT.sol
+++ b/tests/src/eth/api/UniqueNFT.sol
@@ -72,6 +72,7 @@
 /// @title A contract that allows you to work with collections.
 <<<<<<< HEAD
 <<<<<<< HEAD
+<<<<<<< HEAD
 /// @dev the ERC-165 identifier for this interface is 0xb3152af3
 =======
 /// @dev the ERC-165 identifier for this interface is 0x674be726
@@ -79,6 +80,9 @@
 =======
 /// @dev the ERC-165 identifier for this interface is 0x943ee094
 >>>>>>> fix: after rebase
+=======
+/// @dev the ERC-165 identifier for this interface is 0xefe988e0
+>>>>>>> misk: update stubs
 interface Collection is Dummy, ERC165 {
 	/// Set collection property.
 	///
@@ -91,7 +95,7 @@
 	/// Set collection properties.
 	///
 	/// @param properties Vector of properties key/value pair.
-	/// @dev EVM selector for this function is: 0xf90c1ce9,
+	/// @dev EVM selector for this function is: 0x50b26b2a,
 	///  or in textual repr: setCollectionProperties((string,bytes)[])
 	function setCollectionProperties(Tuple21[] memory properties) external;
 
@@ -105,7 +109,7 @@
 	/// Delete collection properties.
 	///
 	/// @param keys Properties keys.
-	/// @dev EVM selector for this function is: 0x56d4684a,
+	/// @dev EVM selector for this function is: 0xee206ee3,
 	///  or in textual repr: deleteCollectionProperties(string[])
 	function deleteCollectionProperties(string[] memory keys) external;
 
@@ -123,7 +127,7 @@
 	///
 	/// @param keys Properties keys. Empty keys for all propertyes.
 	/// @return Vector of properties key/value pairs.
-	/// @dev EVM selector for this function is: 0x5cad7311,
+	/// @dev EVM selector for this function is: 0x285fb8e6,
 	///  or in textual repr: collectionProperties(string[])
 	function collectionProperties(string[] memory keys) external view returns (Tuple21[] memory);
 
@@ -141,9 +145,16 @@
 	/// @dev In order for sponsorship to work, it must be confirmed on behalf of the sponsor.
 	///
 	/// @param sponsor Cross account address of the sponsor from whose account funds will be debited for operations with the contract.
+<<<<<<< HEAD
 	/// @dev EVM selector for this function is: 0x403e96a7,
 	///  or in textual repr: setCollectionSponsorCross((address,uint256))
 	function setCollectionSponsorCross(Tuple6 memory sponsor) external;
+=======
+	/// @dev EVM selector for this function is: 0x84a1d5a8,
+	///  or in textual repr: setCollectionSponsorCross(EthCrossAccount)
+	///  or in the expanded repr: setCollectionSponsorCross((address,uint256))
+	function setCollectionSponsorCross(EthCrossAccount memory sponsor) external;
+>>>>>>> misk: update stubs
 
 	/// Whether there is a pending sponsor.
 	/// @dev EVM selector for this function is: 0x058ac185,
@@ -167,7 +178,7 @@
 	/// @return Tuble with sponsor address and his substrate mirror. If there is no confirmed sponsor error "Contract has no sponsor" throw.
 	/// @dev EVM selector for this function is: 0x6ec0a9f1,
 	///  or in textual repr: collectionSponsor()
-	function collectionSponsor() external view returns (Tuple8 memory);
+	function collectionSponsor() external view returns (Tuple24 memory);
 
 	/// Set limits for the collection.
 	/// @dev Throws error if limit not found.
@@ -201,6 +212,7 @@
 
 	/// Add collection admin.
 	/// @param newAdmin Cross account administrator address.
+<<<<<<< HEAD
 	/// @dev EVM selector for this function is: 0x62e3c7c2,
 	///  or in textual repr: addCollectionAdminCross((address,uint256))
 	function addCollectionAdminCross(Tuple6 memory newAdmin) external;
@@ -210,6 +222,19 @@
 	/// @dev EVM selector for this function is: 0x810d1503,
 	///  or in textual repr: removeCollectionAdminCross((address,uint256))
 	function removeCollectionAdminCross(Tuple6 memory admin) external;
+=======
+	/// @dev EVM selector for this function is: 0x859aa7d6,
+	///  or in textual repr: addCollectionAdminCross(EthCrossAccount)
+	///  or in the expanded repr: addCollectionAdminCross((address,uint256))
+	function addCollectionAdminCross(EthCrossAccount memory newAdmin) external;
+
+	/// Remove collection admin.
+	/// @param admin Cross account administrator address.
+	/// @dev EVM selector for this function is: 0x6c0cd173,
+	///  or in textual repr: removeCollectionAdminCross(EthCrossAccount)
+	///  or in the expanded repr: removeCollectionAdminCross((address,uint256))
+	function removeCollectionAdminCross(EthCrossAccount memory admin) external;
+>>>>>>> misk: update stubs
 
 	/// Add collection admin.
 	/// @param newAdmin Address of the added administrator.
@@ -235,7 +260,7 @@
 	///
 	/// @param enable If "true" degenerates to nesting: {OwnerRestricted: [1, 2, 3]} else to nesting: 'Disabled'
 	/// @param collections Addresses of collections that will be available for nesting.
-	/// @dev EVM selector for this function is: 0x112d4586,
+	/// @dev EVM selector for this function is: 0x64872396,
 	///  or in textual repr: setCollectionNesting(bool,address[])
 	function setCollectionNesting(bool enable, address[] memory collections) external;
 
@@ -264,9 +289,16 @@
 	/// Add user to allowed list.
 	///
 	/// @param user User cross account address.
+<<<<<<< HEAD
 	/// @dev EVM selector for this function is: 0xf074da88,
 	///  or in textual repr: addToCollectionAllowListCross((address,uint256))
 	function addToCollectionAllowListCross(Tuple6 memory user) external;
+=======
+	/// @dev EVM selector for this function is: 0xa0184a3a,
+	///  or in textual repr: addToCollectionAllowListCross(EthCrossAccount)
+	///  or in the expanded repr: addToCollectionAllowListCross((address,uint256))
+	function addToCollectionAllowListCross(EthCrossAccount memory user) external;
+>>>>>>> misk: update stubs
 
 	/// Remove the user from the allowed list.
 	///
@@ -278,9 +310,16 @@
 	/// Remove user from allowed list.
 	///
 	/// @param user User cross account address.
+<<<<<<< HEAD
 	/// @dev EVM selector for this function is: 0xc00df45c,
 	///  or in textual repr: removeFromCollectionAllowListCross((address,uint256))
 	function removeFromCollectionAllowListCross(Tuple6 memory user) external;
+=======
+	/// @dev EVM selector for this function is: 0x09ba452a,
+	///  or in textual repr: removeFromCollectionAllowListCross(EthCrossAccount)
+	///  or in the expanded repr: removeFromCollectionAllowListCross((address,uint256))
+	function removeFromCollectionAllowListCross(EthCrossAccount memory user) external;
+>>>>>>> misk: update stubs
 
 	/// Switch permission for minting.
 	///
@@ -301,9 +340,16 @@
 	///
 	/// @param user User cross account to verify
 	/// @return "true" if account is the owner or admin
+<<<<<<< HEAD
 	/// @dev EVM selector for this function is: 0x5aba3351,
 	///  or in textual repr: isOwnerOrAdminCross((address,uint256))
 	function isOwnerOrAdminCross(Tuple6 memory user) external view returns (bool);
+=======
+	/// @dev EVM selector for this function is: 0x3e75a905,
+	///  or in textual repr: isOwnerOrAdminCross(EthCrossAccount)
+	///  or in the expanded repr: isOwnerOrAdminCross((address,uint256))
+	function isOwnerOrAdminCross(EthCrossAccount memory user) external view returns (bool);
+>>>>>>> misk: update stubs
 
 	/// Returns collection type
 	///
@@ -318,7 +364,7 @@
 	/// If address is canonical then substrate mirror is zero and vice versa.
 	/// @dev EVM selector for this function is: 0xdf727d3b,
 	///  or in textual repr: collectionOwner()
-	function collectionOwner() external view returns (Tuple8 memory);
+	function collectionOwner() external view returns (EthCrossAccount memory);
 
 	/// Changes collection owner to another account
 	///
@@ -334,15 +380,38 @@
 	/// If address is canonical then substrate mirror is zero and vice versa.
 	/// @dev EVM selector for this function is: 0x5813216b,
 	///  or in textual repr: collectionAdmins()
+<<<<<<< HEAD
 	function collectionAdmins() external view returns (Tuple6[] memory);
+=======
+	function collectionAdmins() external view returns (EthCrossAccount[] memory);
+>>>>>>> misk: update stubs
 
 	/// Changes collection owner to another account
 	///
 	/// @dev Owner can be changed only by current owner
 	/// @param newOwner new owner cross account
+<<<<<<< HEAD
 	/// @dev EVM selector for this function is: 0xbdff793d,
 	///  or in textual repr: setOwnerCross((address,uint256))
 	function setOwnerCross(Tuple6 memory newOwner) external;
+=======
+	/// @dev EVM selector for this function is: 0xe5c9913f,
+	///  or in textual repr: setOwnerCross(EthCrossAccount)
+	///  or in the expanded repr: setOwnerCross((address,uint256))
+	function setOwnerCross(EthCrossAccount memory newOwner) external;
+}
+
+/// @dev Cross account struct
+struct EthCrossAccount {
+	address eth;
+	uint256 sub;
+}
+
+/// @dev anonymous struct
+struct Tuple24 {
+	address field_0;
+	uint256 field_1;
+>>>>>>> misk: update stubs
 }
 
 <<<<<<< HEAD
@@ -459,10 +528,14 @@
 
 /// @title Unique extensions for ERC721.
 <<<<<<< HEAD
+<<<<<<< HEAD
 /// @dev the ERC-165 identifier for this interface is 0x244543ee
 =======
 /// @dev the ERC-165 identifier for this interface is 0xcc97cb35
 >>>>>>> feat: Add custum signature with unlimited nesting.
+=======
+/// @dev the ERC-165 identifier for this interface is 0xb76006ac
+>>>>>>> misk: update stubs
 interface ERC721UniqueExtensions is Dummy, ERC165 {
 	/// @notice A descriptive name for a collection of NFTs in this contract
 	/// @dev EVM selector for this function is: 0x06fdde03,
@@ -480,9 +553,16 @@
 	///  operator of the current owner.
 	/// @param approved The new substrate address approved NFT controller
 	/// @param tokenId The NFT to approve
+<<<<<<< HEAD
 	/// @dev EVM selector for this function is: 0x106fdb59,
 	///  or in textual repr: approveCross((address,uint256),uint256)
 	function approveCross(Tuple6 memory approved, uint256 tokenId) external;
+=======
+	/// @dev EVM selector for this function is: 0x0ecd0ab0,
+	///  or in textual repr: approveCross(EthCrossAccount,uint256)
+	///  or in the expanded repr: approveCross((address,uint256),uint256)
+	function approveCross(EthCrossAccount memory approved, uint256 tokenId) external;
+>>>>>>> misk: update stubs
 
 	/// @notice Transfer ownership of an NFT
 	/// @dev Throws unless `msg.sender` is the current owner. Throws if `to`
@@ -501,6 +581,7 @@
 	/// @param tokenId The NFT to transfer
 	/// @dev EVM selector for this function is: 0xd5cf430b,
 	///  or in textual repr: transferFromCross(EthCrossAccount,EthCrossAccount,uint256)
+	///  or in the expanded repr: transferFromCross((address,uint256),(address,uint256),uint256)
 	function transferFromCross(
 <<<<<<< HEAD
 		Tuple6 memory from,
@@ -528,9 +609,16 @@
 	///  if `to` is the zero address. Throws if `tokenId` is not a valid NFT.
 	/// @param from The current owner of the NFT
 	/// @param tokenId The NFT to transfer
+<<<<<<< HEAD
 	/// @dev EVM selector for this function is: 0xa8106d4a,
 	///  or in textual repr: burnFromCross((address,uint256),uint256)
 	function burnFromCross(Tuple6 memory from, uint256 tokenId) external;
+=======
+	/// @dev EVM selector for this function is: 0xbb2f5a58,
+	///  or in textual repr: burnFromCross(EthCrossAccount,uint256)
+	///  or in the expanded repr: burnFromCross((address,uint256),uint256)
+	function burnFromCross(EthCrossAccount memory from, uint256 tokenId) external;
+>>>>>>> misk: update stubs
 
 	/// @notice Returns next free NFT ID.
 	/// @dev EVM selector for this function is: 0x75794a3c,
@@ -565,7 +653,7 @@
 	///  should be obtained with `nextTokenId` method
 	/// @param to The new owner
 	/// @param tokenIds IDs of the minted NFTs
-	/// @dev EVM selector for this function is: 0xf9d9a5a3,
+	/// @dev EVM selector for this function is: 0x44a9945e,
 	///  or in textual repr: mintBulk(address,uint256[])
 	function mintBulk(address to, uint256[] memory tokenIds) external returns (bool);
 
@@ -574,7 +662,7 @@
 	///  numbers and first number should be obtained with `nextTokenId` method
 	/// @param to The new owner
 	/// @param tokens array of pairs of token ID and token URI for minted tokens
-	/// @dev EVM selector for this function is: 0xfd4e2a99,
+	/// @dev EVM selector for this function is: 0x36543006,
 	///  or in textual repr: mintBulkWithTokenURI(address,(uint256,string)[])
 	function mintBulkWithTokenURI(address to, Tuple12[] memory tokens) external returns (bool);
 }
@@ -586,6 +674,7 @@
 	string field_1;
 }
 
+<<<<<<< HEAD
 /// @dev anonymous struct
 struct Tuple8 {
 	address field_0;
@@ -598,6 +687,8 @@
 	uint256 field_1;
 }
 
+=======
+>>>>>>> misk: update stubs
 /// @title ERC-721 Non-Fungible Token Standard, optional enumeration extension
 /// @dev See https://eips.ethereum.org/EIPS/eip-721
 /// @dev the ERC-165 identifier for this interface is 0x780e9d63
modifiedtests/src/eth/api/UniqueRefungible.soldiffbeforeafterboth
--- a/tests/src/eth/fungibleAbi.json
+++ b/tests/src/eth/fungibleAbi.json
@@ -62,10 +62,15 @@
     "inputs": [
       {
         "components": [
+<<<<<<< HEAD
           { "internalType": "address", "name": "field_0", "type": "address" },
           { "internalType": "uint256", "name": "field_1", "type": "uint256" }
+=======
+          { "internalType": "address", "name": "eth", "type": "address" },
+          { "internalType": "uint256", "name": "sub", "type": "uint256" }
+>>>>>>> misk: update stubs
         ],
-        "internalType": "struct Tuple6",
+        "internalType": "struct EthCrossAccount",
         "name": "newAdmin",
         "type": "tuple"
       }
@@ -88,10 +93,15 @@
     "inputs": [
       {
         "components": [
+<<<<<<< HEAD
           { "internalType": "address", "name": "field_0", "type": "address" },
           { "internalType": "uint256", "name": "field_1", "type": "uint256" }
+=======
+          { "internalType": "address", "name": "eth", "type": "address" },
+          { "internalType": "uint256", "name": "sub", "type": "uint256" }
+>>>>>>> misk: update stubs
         ],
-        "internalType": "struct Tuple6",
+        "internalType": "struct EthCrossAccount",
         "name": "user",
         "type": "tuple"
       }
@@ -134,10 +144,15 @@
     "inputs": [
       {
         "components": [
+<<<<<<< HEAD
           { "internalType": "address", "name": "field_0", "type": "address" },
           { "internalType": "uint256", "name": "field_1", "type": "uint256" }
+=======
+          { "internalType": "address", "name": "eth", "type": "address" },
+          { "internalType": "uint256", "name": "sub", "type": "uint256" }
+>>>>>>> misk: update stubs
         ],
-        "internalType": "struct Tuple6",
+        "internalType": "struct EthCrossAccount",
         "name": "spender",
         "type": "tuple"
       },
@@ -171,10 +186,15 @@
     "inputs": [
       {
         "components": [
+<<<<<<< HEAD
           { "internalType": "address", "name": "field_0", "type": "address" },
           { "internalType": "uint256", "name": "field_1", "type": "uint256" }
+=======
+          { "internalType": "address", "name": "eth", "type": "address" },
+          { "internalType": "uint256", "name": "sub", "type": "uint256" }
+>>>>>>> misk: update stubs
         ],
-        "internalType": "struct Tuple6",
+        "internalType": "struct EthCrossAccount",
         "name": "from",
         "type": "tuple"
       },
@@ -182,6 +202,7 @@
     ],
     "name": "burnFromCross",
     "outputs": [{ "internalType": "bool", "name": "", "type": "bool" }],
+<<<<<<< HEAD
     "stateMutability": "nonpayable",
     "type": "function"
   },
@@ -191,6 +212,8 @@
     ],
     "name": "changeCollectionOwner",
     "outputs": [],
+=======
+>>>>>>> misk: update stubs
     "stateMutability": "nonpayable",
     "type": "function"
   },
@@ -200,10 +223,15 @@
     "outputs": [
       {
         "components": [
+<<<<<<< HEAD
           { "internalType": "address", "name": "field_0", "type": "address" },
           { "internalType": "uint256", "name": "field_1", "type": "uint256" }
+=======
+          { "internalType": "address", "name": "eth", "type": "address" },
+          { "internalType": "uint256", "name": "sub", "type": "uint256" }
+>>>>>>> misk: update stubs
         ],
-        "internalType": "struct Tuple6[]",
+        "internalType": "struct EthCrossAccount[]",
         "name": "",
         "type": "tuple[]"
       }
@@ -217,10 +245,15 @@
     "outputs": [
       {
         "components": [
+<<<<<<< HEAD
           { "internalType": "address", "name": "field_0", "type": "address" },
           { "internalType": "uint256", "name": "field_1", "type": "uint256" }
+=======
+          { "internalType": "address", "name": "eth", "type": "address" },
+          { "internalType": "uint256", "name": "sub", "type": "uint256" }
+>>>>>>> misk: update stubs
         ],
-        "internalType": "struct Tuple6",
+        "internalType": "struct EthCrossAccount",
         "name": "",
         "type": "tuple"
       }
@@ -239,7 +272,7 @@
           { "internalType": "string", "name": "field_0", "type": "string" },
           { "internalType": "bytes", "name": "field_1", "type": "bytes" }
         ],
-        "internalType": "struct Tuple10[]",
+        "internalType": "struct Tuple14[]",
         "name": "",
         "type": "tuple[]"
       }
@@ -263,7 +296,7 @@
           { "internalType": "address", "name": "field_0", "type": "address" },
           { "internalType": "uint256", "name": "field_1", "type": "uint256" }
         ],
-        "internalType": "struct Tuple6",
+        "internalType": "struct Tuple8",
         "name": "",
         "type": "tuple"
       }
@@ -328,10 +361,15 @@
     "inputs": [
       {
         "components": [
+<<<<<<< HEAD
           { "internalType": "address", "name": "field_0", "type": "address" },
           { "internalType": "uint256", "name": "field_1", "type": "uint256" }
+=======
+          { "internalType": "address", "name": "eth", "type": "address" },
+          { "internalType": "uint256", "name": "sub", "type": "uint256" }
+>>>>>>> misk: update stubs
         ],
-        "internalType": "struct Tuple6",
+        "internalType": "struct EthCrossAccount",
         "name": "user",
         "type": "tuple"
       }
@@ -358,7 +396,7 @@
           { "internalType": "address", "name": "field_0", "type": "address" },
           { "internalType": "uint256", "name": "field_1", "type": "uint256" }
         ],
-        "internalType": "struct Tuple6[]",
+        "internalType": "struct Tuple8[]",
         "name": "amounts",
         "type": "tuple[]"
       }
@@ -388,10 +426,15 @@
     "inputs": [
       {
         "components": [
+<<<<<<< HEAD
           { "internalType": "address", "name": "field_0", "type": "address" },
           { "internalType": "uint256", "name": "field_1", "type": "uint256" }
+=======
+          { "internalType": "address", "name": "eth", "type": "address" },
+          { "internalType": "uint256", "name": "sub", "type": "uint256" }
+>>>>>>> misk: update stubs
         ],
-        "internalType": "struct Tuple6",
+        "internalType": "struct EthCrossAccount",
         "name": "admin",
         "type": "tuple"
       }
@@ -421,10 +464,15 @@
     "inputs": [
       {
         "components": [
+<<<<<<< HEAD
           { "internalType": "address", "name": "field_0", "type": "address" },
           { "internalType": "uint256", "name": "field_1", "type": "uint256" }
+=======
+          { "internalType": "address", "name": "eth", "type": "address" },
+          { "internalType": "uint256", "name": "sub", "type": "uint256" }
+>>>>>>> misk: update stubs
         ],
-        "internalType": "struct Tuple6",
+        "internalType": "struct EthCrossAccount",
         "name": "user",
         "type": "tuple"
       }
@@ -496,7 +544,7 @@
           { "internalType": "string", "name": "field_0", "type": "string" },
           { "internalType": "bytes", "name": "field_1", "type": "bytes" }
         ],
-        "internalType": "struct Tuple10[]",
+        "internalType": "struct Tuple14[]",
         "name": "properties",
         "type": "tuple[]"
       }
@@ -529,10 +577,15 @@
     "inputs": [
       {
         "components": [
+<<<<<<< HEAD
           { "internalType": "address", "name": "field_0", "type": "address" },
           { "internalType": "uint256", "name": "field_1", "type": "uint256" }
+=======
+          { "internalType": "address", "name": "eth", "type": "address" },
+          { "internalType": "uint256", "name": "sub", "type": "uint256" }
+>>>>>>> misk: update stubs
         ],
-        "internalType": "struct Tuple6",
+        "internalType": "struct EthCrossAccount",
         "name": "sponsor",
         "type": "tuple"
       }
@@ -544,12 +597,28 @@
   },
   {
     "inputs": [
+<<<<<<< HEAD
       {
         "components": [
           { "internalType": "address", "name": "field_0", "type": "address" },
           { "internalType": "uint256", "name": "field_1", "type": "uint256" }
+=======
+      { "internalType": "address", "name": "newOwner", "type": "address" }
+    ],
+    "name": "setOwner",
+    "outputs": [],
+    "stateMutability": "nonpayable",
+    "type": "function"
+  },
+  {
+    "inputs": [
+      {
+        "components": [
+          { "internalType": "address", "name": "eth", "type": "address" },
+          { "internalType": "uint256", "name": "sub", "type": "uint256" }
+>>>>>>> misk: update stubs
         ],
-        "internalType": "struct Tuple6",
+        "internalType": "struct EthCrossAccount",
         "name": "newOwner",
         "type": "tuple"
       }
@@ -607,19 +676,29 @@
     "inputs": [
       {
         "components": [
+<<<<<<< HEAD
           { "internalType": "address", "name": "field_0", "type": "address" },
           { "internalType": "uint256", "name": "field_1", "type": "uint256" }
+=======
+          { "internalType": "address", "name": "eth", "type": "address" },
+          { "internalType": "uint256", "name": "sub", "type": "uint256" }
+>>>>>>> misk: update stubs
         ],
-        "internalType": "struct Tuple6",
+        "internalType": "struct EthCrossAccount",
         "name": "from",
         "type": "tuple"
       },
       {
         "components": [
+<<<<<<< HEAD
           { "internalType": "address", "name": "field_0", "type": "address" },
           { "internalType": "uint256", "name": "field_1", "type": "uint256" }
+=======
+          { "internalType": "address", "name": "eth", "type": "address" },
+          { "internalType": "uint256", "name": "sub", "type": "uint256" }
+>>>>>>> misk: update stubs
         ],
-        "internalType": "struct Tuple6",
+        "internalType": "struct EthCrossAccount",
         "name": "to",
         "type": "tuple"
       },
modifiedtests/src/eth/nonFungibleAbi.jsondiffbeforeafterboth
--- a/tests/src/eth/nonFungibleAbi.json
+++ b/tests/src/eth/nonFungibleAbi.json
@@ -93,10 +93,14 @@
     "inputs": [
       {
         "components": [
-          { "internalType": "address", "name": "field_0", "type": "address" },
-          { "internalType": "uint256", "name": "field_1", "type": "uint256" }
+          { "internalType": "address", "name": "eth", "type": "address" },
+          { "internalType": "uint256", "name": "sub", "type": "uint256" }
         ],
+<<<<<<< HEAD
         "internalType": "struct Tuple6",
+=======
+        "internalType": "struct EthCrossAccount",
+>>>>>>> misk: update stubs
         "name": "newAdmin",
         "type": "tuple"
       }
@@ -119,10 +123,14 @@
     "inputs": [
       {
         "components": [
-          { "internalType": "address", "name": "field_0", "type": "address" },
-          { "internalType": "uint256", "name": "field_1", "type": "uint256" }
+          { "internalType": "address", "name": "eth", "type": "address" },
+          { "internalType": "uint256", "name": "sub", "type": "uint256" }
         ],
+<<<<<<< HEAD
         "internalType": "struct Tuple6",
+=======
+        "internalType": "struct EthCrossAccount",
+>>>>>>> misk: update stubs
         "name": "user",
         "type": "tuple"
       }
@@ -155,10 +163,14 @@
     "inputs": [
       {
         "components": [
-          { "internalType": "address", "name": "field_0", "type": "address" },
-          { "internalType": "uint256", "name": "field_1", "type": "uint256" }
+          { "internalType": "address", "name": "eth", "type": "address" },
+          { "internalType": "uint256", "name": "sub", "type": "uint256" }
         ],
+<<<<<<< HEAD
         "internalType": "struct Tuple6",
+=======
+        "internalType": "struct EthCrossAccount",
+>>>>>>> misk: update stubs
         "name": "approved",
         "type": "tuple"
       },
@@ -201,10 +213,14 @@
     "inputs": [
       {
         "components": [
-          { "internalType": "address", "name": "field_0", "type": "address" },
-          { "internalType": "uint256", "name": "field_1", "type": "uint256" }
+          { "internalType": "address", "name": "eth", "type": "address" },
+          { "internalType": "uint256", "name": "sub", "type": "uint256" }
         ],
+<<<<<<< HEAD
         "internalType": "struct Tuple6",
+=======
+        "internalType": "struct EthCrossAccount",
+>>>>>>> misk: update stubs
         "name": "from",
         "type": "tuple"
       },
@@ -230,10 +246,14 @@
     "outputs": [
       {
         "components": [
-          { "internalType": "address", "name": "field_0", "type": "address" },
-          { "internalType": "uint256", "name": "field_1", "type": "uint256" }
+          { "internalType": "address", "name": "eth", "type": "address" },
+          { "internalType": "uint256", "name": "sub", "type": "uint256" }
         ],
+<<<<<<< HEAD
         "internalType": "struct Tuple6[]",
+=======
+        "internalType": "struct EthCrossAccount[]",
+>>>>>>> misk: update stubs
         "name": "",
         "type": "tuple[]"
       }
@@ -247,11 +267,12 @@
     "outputs": [
       {
         "components": [
-          { "internalType": "address", "name": "field_0", "type": "address" },
-          { "internalType": "uint256", "name": "field_1", "type": "uint256" }
+          { "internalType": "address", "name": "eth", "type": "address" },
+          { "internalType": "uint256", "name": "sub", "type": "uint256" }
         ],
 <<<<<<< HEAD
 <<<<<<< HEAD
+<<<<<<< HEAD
         "internalType": "struct Tuple6",
 =======
         "internalType": "struct Tuple19",
@@ -259,6 +280,9 @@
 =======
         "internalType": "struct Tuple8",
 >>>>>>> feat: Add custum signature with unlimited nesting.
+=======
+        "internalType": "struct EthCrossAccount",
+>>>>>>> misk: update stubs
         "name": "",
         "type": "tuple"
       }
@@ -319,6 +343,7 @@
         ],
 <<<<<<< HEAD
 <<<<<<< HEAD
+<<<<<<< HEAD
         "internalType": "struct Tuple6",
 =======
         "internalType": "struct Tuple19",
@@ -326,6 +351,9 @@
 =======
         "internalType": "struct Tuple8",
 >>>>>>> feat: Add custum signature with unlimited nesting.
+=======
+        "internalType": "struct Tuple24",
+>>>>>>> misk: update stubs
         "name": "",
         "type": "tuple"
       }
@@ -428,10 +456,14 @@
     "inputs": [
       {
         "components": [
-          { "internalType": "address", "name": "field_0", "type": "address" },
-          { "internalType": "uint256", "name": "field_1", "type": "uint256" }
+          { "internalType": "address", "name": "eth", "type": "address" },
+          { "internalType": "uint256", "name": "sub", "type": "uint256" }
         ],
+<<<<<<< HEAD
         "internalType": "struct Tuple6",
+=======
+        "internalType": "struct EthCrossAccount",
+>>>>>>> misk: update stubs
         "name": "user",
         "type": "tuple"
       }
@@ -556,10 +588,14 @@
     "inputs": [
       {
         "components": [
-          { "internalType": "address", "name": "field_0", "type": "address" },
-          { "internalType": "uint256", "name": "field_1", "type": "uint256" }
+          { "internalType": "address", "name": "eth", "type": "address" },
+          { "internalType": "uint256", "name": "sub", "type": "uint256" }
         ],
+<<<<<<< HEAD
         "internalType": "struct Tuple6",
+=======
+        "internalType": "struct EthCrossAccount",
+>>>>>>> misk: update stubs
         "name": "admin",
         "type": "tuple"
       }
@@ -589,10 +625,14 @@
     "inputs": [
       {
         "components": [
-          { "internalType": "address", "name": "field_0", "type": "address" },
-          { "internalType": "uint256", "name": "field_1", "type": "uint256" }
+          { "internalType": "address", "name": "eth", "type": "address" },
+          { "internalType": "uint256", "name": "sub", "type": "uint256" }
         ],
+<<<<<<< HEAD
         "internalType": "struct Tuple6",
+=======
+        "internalType": "struct EthCrossAccount",
+>>>>>>> misk: update stubs
         "name": "user",
         "type": "tuple"
       }
@@ -745,10 +785,14 @@
     "inputs": [
       {
         "components": [
-          { "internalType": "address", "name": "field_0", "type": "address" },
-          { "internalType": "uint256", "name": "field_1", "type": "uint256" }
+          { "internalType": "address", "name": "eth", "type": "address" },
+          { "internalType": "uint256", "name": "sub", "type": "uint256" }
         ],
+<<<<<<< HEAD
         "internalType": "struct Tuple6",
+=======
+        "internalType": "struct EthCrossAccount",
+>>>>>>> misk: update stubs
         "name": "sponsor",
         "type": "tuple"
       }
@@ -785,6 +829,7 @@
       {
         "components": [
 <<<<<<< HEAD
+<<<<<<< HEAD
           { "internalType": "string", "name": "field_0", "type": "string" },
           { "internalType": "bytes", "name": "field_1", "type": "bytes" }
 =======
@@ -795,6 +840,14 @@
         "internalType": "struct Tuple19[]",
         "name": "properties",
         "type": "tuple[]"
+=======
+          { "internalType": "address", "name": "eth", "type": "address" },
+          { "internalType": "uint256", "name": "sub", "type": "uint256" }
+        ],
+        "internalType": "struct EthCrossAccount",
+        "name": "newOwner",
+        "type": "tuple"
+>>>>>>> misk: update stubs
       }
     ],
     "name": "setProperties",
modifiedtests/src/eth/reFungibleAbi.jsondiffbeforeafterboth
--- a/tests/src/eth/reFungibleAbi.json
+++ b/tests/src/eth/reFungibleAbi.json
@@ -93,10 +93,17 @@
     "inputs": [
       {
         "components": [
+<<<<<<< HEAD
           { "internalType": "address", "name": "field_0", "type": "address" },
           { "internalType": "uint256", "name": "field_1", "type": "uint256" }
         ],
         "internalType": "struct Tuple6",
+=======
+          { "internalType": "address", "name": "eth", "type": "address" },
+          { "internalType": "uint256", "name": "sub", "type": "uint256" }
+        ],
+        "internalType": "struct EthCrossAccount",
+>>>>>>> misk: update stubs
         "name": "newAdmin",
         "type": "tuple"
       }
@@ -119,10 +126,17 @@
     "inputs": [
       {
         "components": [
+<<<<<<< HEAD
           { "internalType": "address", "name": "field_0", "type": "address" },
           { "internalType": "uint256", "name": "field_1", "type": "uint256" }
         ],
         "internalType": "struct Tuple6",
+=======
+          { "internalType": "address", "name": "eth", "type": "address" },
+          { "internalType": "uint256", "name": "sub", "type": "uint256" }
+        ],
+        "internalType": "struct EthCrossAccount",
+>>>>>>> misk: update stubs
         "name": "user",
         "type": "tuple"
       }
@@ -183,10 +197,17 @@
     "inputs": [
       {
         "components": [
+<<<<<<< HEAD
           { "internalType": "address", "name": "field_0", "type": "address" },
           { "internalType": "uint256", "name": "field_1", "type": "uint256" }
         ],
         "internalType": "struct Tuple6",
+=======
+          { "internalType": "address", "name": "eth", "type": "address" },
+          { "internalType": "uint256", "name": "sub", "type": "uint256" }
+        ],
+        "internalType": "struct EthCrossAccount",
+>>>>>>> misk: update stubs
         "name": "from",
         "type": "tuple"
       },
@@ -212,10 +233,17 @@
     "outputs": [
       {
         "components": [
+<<<<<<< HEAD
           { "internalType": "address", "name": "field_0", "type": "address" },
           { "internalType": "uint256", "name": "field_1", "type": "uint256" }
         ],
         "internalType": "struct Tuple6[]",
+=======
+          { "internalType": "address", "name": "eth", "type": "address" },
+          { "internalType": "uint256", "name": "sub", "type": "uint256" }
+        ],
+        "internalType": "struct EthCrossAccount[]",
+>>>>>>> misk: update stubs
         "name": "",
         "type": "tuple[]"
       }
@@ -229,10 +257,17 @@
     "outputs": [
       {
         "components": [
+<<<<<<< HEAD
           { "internalType": "address", "name": "field_0", "type": "address" },
           { "internalType": "uint256", "name": "field_1", "type": "uint256" }
         ],
         "internalType": "struct Tuple6",
+=======
+          { "internalType": "address", "name": "eth", "type": "address" },
+          { "internalType": "uint256", "name": "sub", "type": "uint256" }
+        ],
+        "internalType": "struct EthCrossAccount",
+>>>>>>> misk: update stubs
         "name": "",
         "type": "tuple"
       }
@@ -251,7 +286,7 @@
           { "internalType": "string", "name": "field_0", "type": "string" },
           { "internalType": "bytes", "name": "field_1", "type": "bytes" }
         ],
-        "internalType": "struct Tuple19[]",
+        "internalType": "struct Tuple20[]",
         "name": "",
         "type": "tuple[]"
       }
@@ -275,7 +310,11 @@
           { "internalType": "address", "name": "field_0", "type": "address" },
           { "internalType": "uint256", "name": "field_1", "type": "uint256" }
         ],
+<<<<<<< HEAD
         "internalType": "struct Tuple6",
+=======
+        "internalType": "struct Tuple23",
+>>>>>>> misk: update stubs
         "name": "",
         "type": "tuple"
       }
@@ -369,10 +408,17 @@
     "inputs": [
       {
         "components": [
+<<<<<<< HEAD
           { "internalType": "address", "name": "field_0", "type": "address" },
           { "internalType": "uint256", "name": "field_1", "type": "uint256" }
         ],
         "internalType": "struct Tuple6",
+=======
+          { "internalType": "address", "name": "eth", "type": "address" },
+          { "internalType": "uint256", "name": "sub", "type": "uint256" }
+        ],
+        "internalType": "struct EthCrossAccount",
+>>>>>>> misk: update stubs
         "name": "user",
         "type": "tuple"
       }
@@ -383,23 +429,68 @@
     "type": "function"
   },
   {
+<<<<<<< HEAD
     "inputs": [{ "internalType": "address", "name": "to", "type": "address" }],
     "name": "mint",
     "outputs": [{ "internalType": "uint256", "name": "", "type": "uint256" }],
+=======
+    "inputs": [
+      { "internalType": "address", "name": "to", "type": "address" },
+      { "internalType": "uint256", "name": "tokenId", "type": "uint256" }
+    ],
+    "name": "mint",
+    "outputs": [{ "internalType": "bool", "name": "", "type": "bool" }],
+>>>>>>> misk: update stubs
     "stateMutability": "nonpayable",
     "type": "function"
   },
   {
     "inputs": [
       { "internalType": "address", "name": "to", "type": "address" },
+<<<<<<< HEAD
       { "internalType": "string", "name": "tokenUri", "type": "string" }
     ],
     "name": "mintWithTokenURI",
     "outputs": [{ "internalType": "uint256", "name": "", "type": "uint256" }],
+=======
+      { "internalType": "uint256[]", "name": "tokenIds", "type": "uint256[]" }
+    ],
+    "name": "mintBulk",
+    "outputs": [{ "internalType": "bool", "name": "", "type": "bool" }],
     "stateMutability": "nonpayable",
     "type": "function"
   },
   {
+    "inputs": [
+      { "internalType": "address", "name": "to", "type": "address" },
+      {
+        "components": [
+          { "internalType": "uint256", "name": "field_0", "type": "uint256" },
+          { "internalType": "string", "name": "field_1", "type": "string" }
+        ],
+        "internalType": "struct Tuple11[]",
+        "name": "tokens",
+        "type": "tuple[]"
+      }
+    ],
+    "name": "mintBulkWithTokenURI",
+    "outputs": [{ "internalType": "bool", "name": "", "type": "bool" }],
+    "stateMutability": "nonpayable",
+    "type": "function"
+  },
+  {
+    "inputs": [
+      { "internalType": "address", "name": "to", "type": "address" },
+      { "internalType": "uint256", "name": "tokenId", "type": "uint256" },
+      { "internalType": "string", "name": "tokenUri", "type": "string" }
+    ],
+    "name": "mintWithTokenURI",
+    "outputs": [{ "internalType": "bool", "name": "", "type": "bool" }],
+>>>>>>> misk: update stubs
+    "stateMutability": "nonpayable",
+    "type": "function"
+  },
+  {
     "inputs": [],
     "name": "mintingFinished",
     "outputs": [{ "internalType": "bool", "name": "", "type": "bool" }],
@@ -452,10 +543,17 @@
     "inputs": [
       {
         "components": [
+<<<<<<< HEAD
           { "internalType": "address", "name": "field_0", "type": "address" },
           { "internalType": "uint256", "name": "field_1", "type": "uint256" }
         ],
         "internalType": "struct Tuple6",
+=======
+          { "internalType": "address", "name": "eth", "type": "address" },
+          { "internalType": "uint256", "name": "sub", "type": "uint256" }
+        ],
+        "internalType": "struct EthCrossAccount",
+>>>>>>> misk: update stubs
         "name": "admin",
         "type": "tuple"
       }
@@ -485,10 +583,17 @@
     "inputs": [
       {
         "components": [
+<<<<<<< HEAD
           { "internalType": "address", "name": "field_0", "type": "address" },
           { "internalType": "uint256", "name": "field_1", "type": "uint256" }
         ],
         "internalType": "struct Tuple6",
+=======
+          { "internalType": "address", "name": "eth", "type": "address" },
+          { "internalType": "uint256", "name": "sub", "type": "uint256" }
+        ],
+        "internalType": "struct EthCrossAccount",
+>>>>>>> misk: update stubs
         "name": "user",
         "type": "tuple"
       }
@@ -593,7 +698,7 @@
           { "internalType": "string", "name": "field_0", "type": "string" },
           { "internalType": "bytes", "name": "field_1", "type": "bytes" }
         ],
-        "internalType": "struct Tuple19[]",
+        "internalType": "struct Tuple20[]",
         "name": "properties",
         "type": "tuple[]"
       }
@@ -626,10 +731,17 @@
     "inputs": [
       {
         "components": [
+<<<<<<< HEAD
           { "internalType": "address", "name": "field_0", "type": "address" },
           { "internalType": "uint256", "name": "field_1", "type": "uint256" }
         ],
         "internalType": "struct Tuple6",
+=======
+          { "internalType": "address", "name": "eth", "type": "address" },
+          { "internalType": "uint256", "name": "sub", "type": "uint256" }
+        ],
+        "internalType": "struct EthCrossAccount",
+>>>>>>> misk: update stubs
         "name": "sponsor",
         "type": "tuple"
       }
@@ -641,6 +753,7 @@
   },
   {
     "inputs": [
+<<<<<<< HEAD
       {
         "components": [
           { "internalType": "address", "name": "field_0", "type": "address" },
@@ -650,6 +763,9 @@
         "name": "newOwner",
         "type": "tuple"
       }
+=======
+      { "internalType": "address", "name": "newOwner", "type": "address" }
+>>>>>>> misk: update stubs
     ],
     "name": "setOwnerCross",
     "outputs": [],
@@ -661,12 +777,21 @@
       { "internalType": "uint256", "name": "tokenId", "type": "uint256" },
       {
         "components": [
+<<<<<<< HEAD
           { "internalType": "string", "name": "field_0", "type": "string" },
           { "internalType": "bytes", "name": "field_1", "type": "bytes" }
         ],
         "internalType": "struct Tuple19[]",
         "name": "properties",
         "type": "tuple[]"
+=======
+          { "internalType": "address", "name": "eth", "type": "address" },
+          { "internalType": "uint256", "name": "sub", "type": "uint256" }
+        ],
+        "internalType": "struct EthCrossAccount",
+        "name": "newOwner",
+        "type": "tuple"
+>>>>>>> misk: update stubs
       }
     ],
     "name": "setProperties",
@@ -782,19 +907,33 @@
     "inputs": [
       {
         "components": [
+<<<<<<< HEAD
           { "internalType": "address", "name": "field_0", "type": "address" },
           { "internalType": "uint256", "name": "field_1", "type": "uint256" }
         ],
         "internalType": "struct Tuple6",
+=======
+          { "internalType": "address", "name": "eth", "type": "address" },
+          { "internalType": "uint256", "name": "sub", "type": "uint256" }
+        ],
+        "internalType": "struct EthCrossAccount",
+>>>>>>> misk: update stubs
         "name": "from",
         "type": "tuple"
       },
       {
         "components": [
+<<<<<<< HEAD
           { "internalType": "address", "name": "field_0", "type": "address" },
           { "internalType": "uint256", "name": "field_1", "type": "uint256" }
         ],
         "internalType": "struct Tuple6",
+=======
+          { "internalType": "address", "name": "eth", "type": "address" },
+          { "internalType": "uint256", "name": "sub", "type": "uint256" }
+        ],
+        "internalType": "struct EthCrossAccount",
+>>>>>>> misk: update stubs
         "name": "to",
         "type": "tuple"
       },
--- a/tests/src/eth/api/UniqueRefungible.sol
+++ b/tests/src/eth/api/UniqueRefungible.sol
@@ -85,7 +85,7 @@
 	/// @param properties Vector of properties key/value pair.
 	/// @dev EVM selector for this function is: 0x50b26b2a,
 	///  or in textual repr: setCollectionProperties((string,bytes)[])
-	function setCollectionProperties(Tuple19[] memory properties) external;
+	function setCollectionProperties(Tuple20[] memory properties) external;
 
 	/// Delete collection property.
 	///
@@ -117,7 +117,7 @@
 	/// @return Vector of properties key/value pairs.
 	/// @dev EVM selector for this function is: 0x285fb8e6,
 	///  or in textual repr: collectionProperties(string[])
-	function collectionProperties(string[] memory keys) external view returns (Tuple19[] memory);
+	function collectionProperties(string[] memory keys) external view returns (Tuple20[] memory);
 
 	/// Set the sponsor of the collection.
 	///
@@ -134,8 +134,14 @@
 	///
 	/// @param sponsor Cross account address of the sponsor from whose account funds will be debited for operations with the contract.
 	/// @dev EVM selector for this function is: 0x84a1d5a8,
+<<<<<<< HEAD
 	///  or in textual repr: setCollectionSponsorCross((address,uint256))
 	function setCollectionSponsorCross(Tuple6 memory sponsor) external;
+=======
+	///  or in textual repr: setCollectionSponsorCross(EthCrossAccount)
+	///  or in the expanded repr: setCollectionSponsorCross((address,uint256))
+	function setCollectionSponsorCross(EthCrossAccount memory sponsor) external;
+>>>>>>> misk: update stubs
 
 	/// Whether there is a pending sponsor.
 	/// @dev EVM selector for this function is: 0x058ac185,
@@ -159,7 +165,11 @@
 	/// @return Tuble with sponsor address and his substrate mirror. If there is no confirmed sponsor error "Contract has no sponsor" throw.
 	/// @dev EVM selector for this function is: 0x6ec0a9f1,
 	///  or in textual repr: collectionSponsor()
+<<<<<<< HEAD
 	function collectionSponsor() external view returns (Tuple6 memory);
+=======
+	function collectionSponsor() external view returns (Tuple23 memory);
+>>>>>>> misk: update stubs
 
 	/// Set limits for the collection.
 	/// @dev Throws error if limit not found.
@@ -194,14 +204,26 @@
 	/// Add collection admin.
 	/// @param newAdmin Cross account administrator address.
 	/// @dev EVM selector for this function is: 0x859aa7d6,
+<<<<<<< HEAD
 	///  or in textual repr: addCollectionAdminCross((address,uint256))
 	function addCollectionAdminCross(Tuple6 memory newAdmin) external;
+=======
+	///  or in textual repr: addCollectionAdminCross(EthCrossAccount)
+	///  or in the expanded repr: addCollectionAdminCross((address,uint256))
+	function addCollectionAdminCross(EthCrossAccount memory newAdmin) external;
+>>>>>>> misk: update stubs
 
 	/// Remove collection admin.
 	/// @param admin Cross account administrator address.
 	/// @dev EVM selector for this function is: 0x6c0cd173,
+<<<<<<< HEAD
 	///  or in textual repr: removeCollectionAdminCross((address,uint256))
 	function removeCollectionAdminCross(Tuple6 memory admin) external;
+=======
+	///  or in textual repr: removeCollectionAdminCross(EthCrossAccount)
+	///  or in the expanded repr: removeCollectionAdminCross((address,uint256))
+	function removeCollectionAdminCross(EthCrossAccount memory admin) external;
+>>>>>>> misk: update stubs
 
 	/// Add collection admin.
 	/// @param newAdmin Address of the added administrator.
@@ -257,8 +279,14 @@
 	///
 	/// @param user User cross account address.
 	/// @dev EVM selector for this function is: 0xa0184a3a,
+<<<<<<< HEAD
 	///  or in textual repr: addToCollectionAllowListCross((address,uint256))
 	function addToCollectionAllowListCross(Tuple6 memory user) external;
+=======
+	///  or in textual repr: addToCollectionAllowListCross(EthCrossAccount)
+	///  or in the expanded repr: addToCollectionAllowListCross((address,uint256))
+	function addToCollectionAllowListCross(EthCrossAccount memory user) external;
+>>>>>>> misk: update stubs
 
 	/// Remove the user from the allowed list.
 	///
@@ -271,8 +299,14 @@
 	///
 	/// @param user User cross account address.
 	/// @dev EVM selector for this function is: 0x09ba452a,
+<<<<<<< HEAD
 	///  or in textual repr: removeFromCollectionAllowListCross((address,uint256))
 	function removeFromCollectionAllowListCross(Tuple6 memory user) external;
+=======
+	///  or in textual repr: removeFromCollectionAllowListCross(EthCrossAccount)
+	///  or in the expanded repr: removeFromCollectionAllowListCross((address,uint256))
+	function removeFromCollectionAllowListCross(EthCrossAccount memory user) external;
+>>>>>>> misk: update stubs
 
 	/// Switch permission for minting.
 	///
@@ -294,8 +328,14 @@
 	/// @param user User cross account to verify
 	/// @return "true" if account is the owner or admin
 	/// @dev EVM selector for this function is: 0x3e75a905,
+<<<<<<< HEAD
 	///  or in textual repr: isOwnerOrAdminCross((address,uint256))
 	function isOwnerOrAdminCross(Tuple6 memory user) external view returns (bool);
+=======
+	///  or in textual repr: isOwnerOrAdminCross(EthCrossAccount)
+	///  or in the expanded repr: isOwnerOrAdminCross((address,uint256))
+	function isOwnerOrAdminCross(EthCrossAccount memory user) external view returns (bool);
+>>>>>>> misk: update stubs
 
 	/// Returns collection type
 	///
@@ -306,11 +346,15 @@
 
 	/// Get collection owner.
 	///
-	/// @return Tuble with sponsor address and his substrate mirror.
+	/// @return Tuple with sponsor address and his substrate mirror.
 	/// If address is canonical then substrate mirror is zero and vice versa.
 	/// @dev EVM selector for this function is: 0xdf727d3b,
 	///  or in textual repr: collectionOwner()
+<<<<<<< HEAD
 	function collectionOwner() external view returns (Tuple6 memory);
+=======
+	function collectionOwner() external view returns (EthCrossAccount memory);
+>>>>>>> misk: update stubs
 
 	/// Changes collection owner to another account
 	///
@@ -326,19 +370,41 @@
 	/// If address is canonical then substrate mirror is zero and vice versa.
 	/// @dev EVM selector for this function is: 0x5813216b,
 	///  or in textual repr: collectionAdmins()
+<<<<<<< HEAD
 	function collectionAdmins() external view returns (Tuple6[] memory);
+=======
+	function collectionAdmins() external view returns (EthCrossAccount[] memory);
+>>>>>>> misk: update stubs
 
 	/// Changes collection owner to another account
 	///
 	/// @dev Owner can be changed only by current owner
 	/// @param newOwner new owner cross account
 	/// @dev EVM selector for this function is: 0xe5c9913f,
+<<<<<<< HEAD
 	///  or in textual repr: setOwnerCross((address,uint256))
 	function setOwnerCross(Tuple6 memory newOwner) external;
+=======
+	///  or in textual repr: setOwnerCross(EthCrossAccount)
+	///  or in the expanded repr: setOwnerCross((address,uint256))
+	function setOwnerCross(EthCrossAccount memory newOwner) external;
+}
+
+/// @dev Cross account struct
+struct EthCrossAccount {
+	address eth;
+	uint256 sub;
+}
+
+/// @dev anonymous struct
+struct Tuple23 {
+	address field_0;
+	uint256 field_1;
+>>>>>>> misk: update stubs
 }
 
 /// @dev anonymous struct
-struct Tuple19 {
+struct Tuple20 {
 	string field_0;
 	bytes field_1;
 }
@@ -465,10 +531,16 @@
 	/// @param to The new owner
 	/// @param tokenId The RFT to transfer
 	/// @dev EVM selector for this function is: 0xd5cf430b,
 	///  or in textual repr: transferFromCross((address,uint256),(address,uint256),uint256)
 	function transferFromCross(
+<<<<<<< HEAD
 		Tuple6 memory from,
 		Tuple6 memory to,
+=======
+		EthCrossAccount memory from,
+		EthCrossAccount memory to,
+>>>>>>> misk: update stubs
 		uint256 tokenId
 	) external;
 
@@ -491,14 +563,21 @@
 	/// @param from The current owner of the RFT
 	/// @param tokenId The RFT to transfer
 	/// @dev EVM selector for this function is: 0xbb2f5a58,
+<<<<<<< HEAD
 	///  or in textual repr: burnFromCross((address,uint256),uint256)
 	function burnFromCross(Tuple6 memory from, uint256 tokenId) external;
+=======
+	///  or in textual repr: burnFromCross(EthCrossAccount,uint256)
+	///  or in the expanded repr: burnFromCross((address,uint256),uint256)
+	function burnFromCross(EthCrossAccount memory from, uint256 tokenId) external;
+>>>>>>> misk: update stubs
 
 	/// @notice Returns next free RFT ID.
 	/// @dev EVM selector for this function is: 0x75794a3c,
 	///  or in textual repr: nextTokenId()
 	function nextTokenId() external view returns (uint256);
 
+<<<<<<< HEAD
 	// /// @notice Function to mint multiple tokens.
 	// /// @dev `tokenIds` should be an array of consecutive numbers and first number
 	// ///  should be obtained with `nextTokenId` method
@@ -516,6 +595,25 @@
 	// /// @dev EVM selector for this function is: 0x36543006,
 	// ///  or in textual repr: mintBulkWithTokenURI(address,(uint256,string)[])
 	// function mintBulkWithTokenURI(address to, Tuple8[] memory tokens) external returns (bool);
+=======
+	/// @notice Function to mint multiple tokens.
+	/// @dev `tokenIds` should be an array of consecutive numbers and first number
+	///  should be obtained with `nextTokenId` method
+	/// @param to The new owner
+	/// @param tokenIds IDs of the minted RFTs
+	/// @dev EVM selector for this function is: 0x44a9945e,
+	///  or in textual repr: mintBulk(address,uint256[])
+	function mintBulk(address to, uint256[] memory tokenIds) external returns (bool);
+
+	/// @notice Function to mint multiple tokens with the given tokenUris.
+	/// @dev `tokenIds` is array of pairs of token ID and token URI. Token IDs should be consecutive
+	///  numbers and first number should be obtained with `nextTokenId` method
+	/// @param to The new owner
+	/// @param tokens array of pairs of token ID and token URI for minted tokens
+	/// @dev EVM selector for this function is: 0x36543006,
+	///  or in textual repr: mintBulkWithTokenURI(address,(uint256,string)[])
+	function mintBulkWithTokenURI(address to, Tuple11[] memory tokens) external returns (bool);
+>>>>>>> misk: update stubs
 
 	/// Returns EVM address for refungible token
 	///
@@ -526,17 +624,24 @@
 }
 
 /// @dev anonymous struct
+<<<<<<< HEAD
 struct Tuple8 {
+=======
+struct Tuple11 {
+>>>>>>> misk: update stubs
 	uint256 field_0;
 	string field_1;
 }
 
+<<<<<<< HEAD
 /// @dev anonymous struct
 struct Tuple6 {
 	address field_0;
 	uint256 field_1;
 }
 
+=======
+>>>>>>> misk: update stubs
 /// @title ERC-721 Non-Fungible Token Standard, optional enumeration extension
 /// @dev See https://eips.ethereum.org/EIPS/eip-721
 /// @dev the ERC-165 identifier for this interface is 0x780e9d63
@@ -465,10 +531,16 @@
 	/// @param tokenId The RFT to transfer
 	/// @dev EVM selector for this function is: 0xd5cf430b,
-	///  or in textual repr: transferFromCross((address,uint256),(address,uint256),uint256)
+	///  or in textual repr: transferFromCross(EthCrossAccount,EthCrossAccount,uint256)
+	///  or in the expanded repr: transferFromCross((address,uint256),(address,uint256),uint256)
 	function transferFromCross(
modifiedtests/src/eth/fungibleAbi.jsondiffbeforeafterboth